@@ -1,4 +1,4 @@
-from location import Location
+from .location import Location
 
 
 class Vehicle:
